@@ -234,7 +234,7 @@ c            ------------------------------
       blist(1) = b
       rlist(1) = 0.0d+00
       elist(1) = 0.0d+00
-      if(epsabs.le.0.0d+00.and.epsrel.lt.dmax1(0.5d+02*epmach,0.5d-28))
+      if(epsabs.le.0.0d+00.and.epsrel.lt.max(0.5d+02*epmach,0.5d-28))
      *   ier = 6
       if(ier.eq.6) go to 999
 c
@@ -248,8 +248,8 @@ c
 c
 c           test on accuracy.
 c
-      dres = dabs(result)
-      errbnd = dmax1(epsabs,epsrel*dres)
+      dres = abs(result)
+      errbnd = max(epsabs,epsrel*dres)
       last = 1
       rlist(1) = result
       elist(1) = abserr
@@ -304,14 +304,14 @@ c
         errsum = errsum+erro12-errmax
         area = area+area12-rlist(maxerr)
         if(defab1.eq.error1.or.defab2.eq.error2) go to 15
-        if(dabs(rlist(maxerr)-area12).gt.0.1d-04*dabs(area12)
+        if(abs(rlist(maxerr)-area12).gt.0.1d-04*abs(area12)
      *  .or.erro12.lt.0.99d+00*errmax) go to 10
         if(extrap) iroff2 = iroff2+1
         if(.not.extrap) iroff1 = iroff1+1
    10   if(last.gt.10.and.erro12.gt.errmax) iroff3 = iroff3+1
    15   rlist(maxerr) = area1
         rlist(last) = area2
-        errbnd = dmax1(epsabs,epsrel*dabs(area))
+        errbnd = max(epsabs,epsrel*abs(area))
 c
 c           test for roundoff error and eventually set error flag.
 c
@@ -326,8 +326,8 @@ c
 c           set error flag in the case of bad integrand behaviour
 c           at a point of the integration range.
 c
-        if(dmax1(dabs(a1),dabs(b2)).le.(0.1d+01+0.1d+03*epmach)*
-     *  (dabs(a2)+0.1d+04*uflow)) ier = 4
+        if(max(abs(a1),abs(b2)).le.(0.1d+01+0.1d+03*epmach)*
+     *  (abs(a2)+0.1d+04*uflow)) ier = 4
 c
 c           append the newly-created intervals to the list.
 c
@@ -358,13 +358,13 @@ c ***jump out of do-loop
         if(last.eq.2) go to 80
         if(noext) go to 90
         erlarg = erlarg-erlast
-        if(dabs(b1-a1).gt.small) erlarg = erlarg+erro12
+        if(abs(b1-a1).gt.small) erlarg = erlarg+erro12
         if(extrap) go to 40
 c
 c           test whether the interval to be bisected next is the
 c           smallest interval.
 c
-        if(dabs(blist(maxerr)-alist(maxerr)).gt.small) go to 90
+        if(abs(blist(maxerr)-alist(maxerr)).gt.small) go to 90
         extrap = .true.
         nrmax = 2
    40   if(ierro.eq.3.or.erlarg.le.ertest) go to 60
@@ -380,7 +380,7 @@ c
           maxerr = iord(nrmax)
           errmax = elist(maxerr)
 c ***jump out of do-loop
-          if(dabs(blist(maxerr)-alist(maxerr)).gt.small) go to 90
+          if(abs(blist(maxerr)-alist(maxerr)).gt.small) go to 90
           nrmax = nrmax+1
    50   continue
 c
@@ -396,7 +396,7 @@ c
         abserr = abseps
         result = reseps
         correc = erlarg
-        ertest = dmax1(epsabs,epsrel*dabs(reseps))
+        ertest = max(epsabs,epsrel*abs(reseps))
 c ***jump out of do-loop
         if(abserr.le.ertest) go to 100
 c
@@ -411,7 +411,7 @@ c
         small = small*0.5d+00
         erlarg = errsum
         go to 90
-   80   small = dabs(b-a)*0.375d+00
+   80   small = abs(b-a)*0.375d+00
         erlarg = errsum
         ertest = errbnd
         rlist2(2) = area
@@ -428,14 +428,14 @@ c
       if(abserr.gt.errsum) go to 115
       if(area.eq.0.0d+00) go to 130
       go to 110
-  105 if(abserr/dabs(result).gt.errsum/dabs(area)) go to 115
+  105 if(abserr/abs(result).gt.errsum/abs(area)) go to 115
 c
 c           test on divergence.
 c
-  110 if(ksgn.eq.(-1).and.dmax1(dabs(result),dabs(area)).le.
+  110 if(ksgn.eq.(-1).and.max(abs(result),abs(area)).le.
      * defabs*0.1d-01) go to 130
       if(0.1d-01.gt.(result/area).or.(result/area).gt.0.1d+03
-     * .or.errsum.gt.dabs(area)) ier = 6
+     * .or.errsum.gt.abs(area)) ier = 6
       go to 130
 c
 c           compute global integral sum.
