@@ -155,7 +155,7 @@ c***first executable statement  dqk21
 c
       centr = 0.5d+00*(a+b)
       hlgth = 0.5d+00*(b-a)
-      dhlgth = dabs(hlgth)
+      dhlgth = abs(hlgth)
 c
 c           compute the 21-point kronrod approximation to
 c           the integral, and estimate the absolute error.
@@ -177,7 +177,7 @@ c
       resg = 0.0d+00
 C     fc = f(centr)
       resk = wgk(11)*fc
-      resabs = dabs(resk)
+      resabs = abs(resk)
       do 10 j=1,5
         jtw = 2*j
 C       absc = hlgth*xgk(jtw)
@@ -190,7 +190,7 @@ C       fv2(jtw) = fval2
         fsum = fval1+fval2
         resg = resg+wg(j)*fsum
         resk = resk+wgk(jtw)*fsum
-        resabs = resabs+wgk(jtw)*(dabs(fval1)+dabs(fval2))
+        resabs = resabs+wgk(jtw)*(abs(fval1)+abs(fval2))
    10 continue
       do 15 j = 1,5
         jtwm1 = 2*j-1
@@ -203,19 +203,19 @@ C       fv2(jtwm1) = fval2
           fval2=fv2(jtwm1)
         fsum = fval1+fval2
         resk = resk+wgk(jtwm1)*fsum
-        resabs = resabs+wgk(jtwm1)*(dabs(fval1)+dabs(fval2))
+        resabs = resabs+wgk(jtwm1)*(abs(fval1)+abs(fval2))
    15 continue
       reskh = resk*0.5d+00
-      resasc = wgk(11)*dabs(fc-reskh)
+      resasc = wgk(11)*abs(fc-reskh)
       do 20 j=1,10
-        resasc = resasc+wgk(j)*(dabs(fv1(j)-reskh)+dabs(fv2(j)-reskh))
+        resasc = resasc+wgk(j)*(abs(fv1(j)-reskh)+abs(fv2(j)-reskh))
    20 continue
       result = resk*hlgth
       resabs = resabs*dhlgth
       resasc = resasc*dhlgth
-      abserr = dabs((resk-resg)*hlgth)
+      abserr = abs((resk-resg)*hlgth)
       if(resasc.ne.0.0d+00.and.abserr.ne.0.0d+00)
-     *  abserr = resasc*dmin1(0.1d+01,(0.2d+03*abserr/resasc)**1.5d+00)
+     *  abserr = resasc*min(0.1d+01,(0.2d+03*abserr/resasc)**1.5d+00)
       if(resabs.gt.uflow/(0.5d+02*epmach)) abserr = dmax1
      *  ((epmach*0.5d+02)*resabs,abserr)
       return
